@@ -16,6 +16,7 @@ from functional_predicates.predicates.builtin import Any
 from functional_predicates.predicates.builtin import Callable
 from functional_predicates.predicates.builtin import HasAttr
 from functional_predicates.predicates.builtin import IsInstance
+from functional_predicates.predicates.builtin import IsSubClass
 from functional_predicates.predicates.operator import Contains
 from functional_predicates.predicates.operator import Eq
 from functional_predicates.predicates.operator import GE
@@ -59,6 +60,9 @@ class Checker(Base):
     def isinstance(self: Checker, x: Union[Type, Tuple[Type, ...]]) -> Checker:  # noqa: A003
         return self._append(IsInstance, x)
 
+    def issubclass(self: Checker, x: Type) -> Checker:  # noqa: A003
+        return self._append(IsSubClass, x)
+
     # operator
 
     def lt(self: Checker, x: typing.Any) -> Checker:
