@@ -12,8 +12,4 @@ def red(x: str) -> str:
     return stylize(x, fg("red"))
 
 
-class _Sentinel:
-    ...
-
-
-sentinel = _Sentinel()
+sentinel = object()
