@@ -15,6 +15,7 @@ AnyLike = TypeVar("AnyLike", bound="Any")
 CallableLike = TypeVar("CallableLike", bound="Callable")
 HasAttrLike = TypeVar("HasAttrLike", bound="HasAttr")
 IsInstanceLike = TypeVar("IsInstanceLike", bound="IsInstance")
+IsSubClassLike = TypeVar("IsSubClassLike", bound="IsSubClass")
 
 
 class All(Predicate):
@@ -82,3 +83,20 @@ class IsInstance(Predicate):
 
     def _repr(self: IsInstance) -> str:
         return f"isinstance({self._mb_value}{self._mb_comma_space}{self.class_or_tuple})"
+
+
+class IsSubClass(Predicate):
+    def __init__(
+        self: IsSubClass, class_or_tuple: Union[Type, Tuple[Type, ...]], *, value: Any = sentinel,
+    ) -> None:
+        super().__init__(value=value)
+        self.class_or_tuple = class_or_tuple
+
+    def _bool(self: IsSubClass) -> bool:
+        return issubclass(self.value, self.class_or_tuple)
+
+    def _call(self: IsSubClassLike, value: typing.Any) -> IsSubClassLike:
+        return type(self)(self.class_or_tuple, value=value)
+
+    def _repr(self: IsSubClass) -> str:
+        return f"issubclass({self._mb_value}{self._mb_comma_space}{self.class_or_tuple})"
